#!/usr/bin/python
import requests
import base64


def url2base64(url):
    return "data:image/jpeg;base64,"+base64.b64encode(requests.get(url).content).decode()


def file2base64(path):
    with open(path, "rb") as file:
        return "data:image/jpeg;base64,"+base64.b64encode(file.read()).decode()



#!/usr/bin/python
from imgbase64 import *
import argparse

parser = argparse.ArgumentParser(description='Process some integers.')
parser.add_argument('--url', help='specify the url to image', type=str)
parser.add_argument('--file', help='specify the path to image', type=str)

args = parser.parse_args()

if args.url:
    print(url2base64(args.url))
elif args.file:
    print(file2base64(args.file))



# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='imgbase64',
    version='0.1.3',
    url='https://github.com/Ronnasayd/imgbase64',
    license='MIT License',
    author='Ronnasayd de Sousa Machado',
    author_email='ronnasayd@hotmail.com',
    keywords='image bas64 url',
    description=u'Transforma images em base64',
    packages=['imgbase64'],
    install_requires=['argparse', 'requests'],
)
